@@ -80,12 +80,11 @@ def interact(argv=sys.argv):  # pragma: no cover
                 # ipython >= 0.11
                 from IPython.frontend.terminal.embed import \
                     InteractiveShellEmbed
-            try:
-                # ipython >= 4
-                from traitlets.config.loader import Config
-            except ImportError:
-                # ipython >= 0.11
+            import IPython
+            if IPython.version_info < (4,):
                 from IPython.config.loader import Config
+            else:
+                from traitlets.config.loader import Config
             cfg = Config()
             try:
                 # >= 0.12
