@@ -14,9 +14,11 @@ class TestAgent(object):
     """Agent for testing purpose"""
 
     def __init__(self, ipv6=False, community='public',
-                 authpass='authpass', privpass='privpass'):
+                 authpass='authpass', privpass='privpass',
+                 emptyTable=True):
         q = Queue()
         self.ipv6 = ipv6
+        self.emptyTable = emptyTable
         self.community = community
         self.authpass = authpass
         self.privpass = privpass
@@ -93,8 +95,13 @@ class TestAgent(object):
             MibScalar((1, 3, 6, 1, 2, 1, 1, 1), v2c.OctetString()),
             MibScalarInstance((1, 3, 6, 1, 2, 1, 1, 1), (0,),
                               v2c.OctetString(
-                                  "Snimpy Test Agent {}".format(
-                                      self.community))))
+                                  "Snimpy Test Agent {0}".format(
+                                      self.community))),
+            # SNMPv2-MIB::sysObjectID
+            MibScalar((1, 3, 6, 1, 2, 1, 1, 2), v2c.ObjectIdentifier()),
+            MibScalarInstance((1, 3, 6, 1, 2, 1, 1, 2), (0,),
+                              v2c.ObjectIdentifier((1, 3, 6, 1, 4,
+                                                    1, 9, 1, 1208))))
         mibBuilder.exportSymbols(
             '__MY_IF_MIB',
             # IF-MIB::ifNumber
@@ -135,10 +142,44 @@ class TestAgent(object):
                 (1, 3, 6, 1, 2, 1, 2, 2, 1, 10), (2,), v2c.Gauge32()),
             RandomMibScalarInstance(
                 (1, 3, 6, 1, 2, 1, 2, 2, 1, 10), (3,), v2c.Gauge32()),
+
+            # IF-MIB::ifRcvAddressTable
+            MibTable((1, 3, 6, 1, 2, 1, 31, 1, 4)),
+            MibTableRow((1, 3, 6, 1, 2, 1, 31, 1, 4, 1)).setIndexNames(
+                (0, '__MY_IF_MIB', 'ifIndex'),
+                (1, '__MY_IF_MIB', 'ifRcvAddressAddress')),
+            # IF-MIB::ifRcvAddressStatus
+            MibTableColumn((1, 3, 6, 1, 2, 1, 31, 1, 4, 1, 2), v2c.Integer()),
+            MibScalarInstance(
+                (1, 3, 6, 1, 2, 1, 31, 1, 4, 1, 2),
+                flatten(2, 6, stringToOid("abcdef")), v2c.Integer(1)),
+            MibScalarInstance(
+                (1, 3, 6, 1, 2, 1, 31, 1, 4, 1, 2),
+                flatten(2, 6, stringToOid("ghijkl")), v2c.Integer(1)),
+            MibScalarInstance(
+                (1, 3, 6, 1, 2, 1, 31, 1, 4, 1, 2),
+                flatten(3, 6, stringToOid("mnopqr")), v2c.Integer(1)),
+            # IF-MIB::ifRcvAddressType
+            MibTableColumn((1, 3, 6, 1, 2, 1, 31, 1, 4, 1, 3), v2c.Integer()),
+            MibScalarInstance(
+                (1, 3, 6, 1, 2, 1, 31, 1, 4, 1, 3),
+                flatten(2, 6, stringToOid("abcdef")), v2c.Integer(1)),
+            MibScalarInstance(
+                (1, 3, 6, 1, 2, 1, 31, 1, 4, 1, 3),
+                flatten(2, 6, stringToOid("ghijkl")), v2c.Integer(1)),
+            MibScalarInstance(
+                (1, 3, 6, 1, 2, 1, 31, 1, 4, 1, 3),
+                flatten(3, 6, stringToOid("mnopqr")), v2c.Integer(1)),
+
             # IF-MIB::ifIndex
             ifIndex=MibTableColumn((1, 3, 6, 1, 2, 1, 2, 2, 1, 1),
-                                   v2c.Integer()))
-        mibBuilder.exportSymbols(
+                                   v2c.Integer()),
+            # IF-MIB::ifRcvAddressAddress
+            ifRcvAddressAddress=MibTableColumn((1, 3, 6, 1, 2, 1, 31,
+                                                1, 4, 1, 1),
+                                               v2c.OctetString()))
+
+        args = (
             '__MY_SNIMPY-MIB',
             # SNIMPY-MIB::snimpyIpAddress
             MibScalar((1, 3, 6, 1, 2, 1, 45121, 1, 1),
@@ -218,6 +259,25 @@ class TestAgent(object):
                 (0, "__MY_SNIMPY-MIB", "snimpyIndexOidVarLen"),
                 (0, "__MY_SNIMPY-MIB", "snimpyIndexFixedLen"),
                 (1, "__MY_SNIMPY-MIB", "snimpyIndexImplied")),
+            # SNIMPY-MIB::snimpyIndexVarLen
+            MibScalarInstance((1, 3, 6, 1, 2, 1, 45121, 2, 3, 1, 1),
+                              flatten(4, stringToOid('row1'),
+                                      3, 1, 2, 3,
+                                      stringToOid('alpha5'),
+                                      stringToOid('end of row1')),
+                              v2c.OctetString(b"row1")),
+            MibScalarInstance((1, 3, 6, 1, 2, 1, 45121, 2, 3, 1, 1),
+                              flatten(4, stringToOid('row2'),
+                                      4, 1, 0, 2, 3,
+                                      stringToOid('beta32'),
+                                      stringToOid('end of row2')),
+                              v2c.OctetString(b"row2")),
+            MibScalarInstance((1, 3, 6, 1, 2, 1, 45121, 2, 3, 1, 1),
+                              flatten(4, stringToOid('row3'),
+                                      4, 120, 1, 2, 3,
+                                      stringToOid('gamma7'),
+                                      stringToOid('end of row3')),
+                              v2c.OctetString(b"row3")),
             # SNIMPY-MIB::snimpyIndexInt
             MibScalarInstance((1, 3, 6, 1, 2, 1, 45121, 2, 3, 1, 6),
                               flatten(4, stringToOid('row1'),
@@ -249,13 +309,22 @@ class TestAgent(object):
                               v2c.OctetString(b"Hello")),
             MibScalarInstance((1, 3, 6, 1, 2, 1, 45121, 2, 5, 1, 2),
                               (2,),
-                              v2c.OctetString(b"\xf1\x12\x13\x14\x15\x16")),
+                              v2c.OctetString(b"\xf1\x12\x13\x14\x15\x16")))
 
+        if self.emptyTable:
+            args += (
+                # SNIMPY-MIB::snimpyEmptyTable
+                MibTable((1, 3, 6, 1, 2, 1, 45121, 2, 6)),
+                MibTableRow(
+                    (1, 3, 6, 1, 2, 1, 45121, 2, 6, 1)).setIndexNames(
+                        (0, "__MY_SNIMPY-MIB", "snimpyEmptyIndex")))
+
+        kwargs = dict(
             # Indexes
             snimpyIndexVarLen=MibTableColumn(
                 (1, 3, 6, 1, 2, 1, 45121, 2, 3, 1, 1),
                 v2c.OctetString(
-                )).setMaxAccess("noaccess"),
+                )),
             snimpyIndexIntIndex=MibTableColumn(
                 (1, 3, 6, 1, 2, 1, 45121, 2, 3, 1, 2),
                 v2c.Integer(
@@ -286,6 +355,18 @@ class TestAgent(object):
                 (1, 3, 6, 1, 2, 1, 45121, 2, 5, 1, 2),
                 v2c.OctetString()).setMaxAccess("readwrite")
         )
+
+        if self.emptyTable:
+            kwargs.update(dict(
+                snimpyEmptyIndex=MibTableColumn(
+                    (1, 3, 6, 1, 2, 1, 45121, 2, 6, 1, 1),
+                    v2c.Integer()).setMaxAccess("noaccess"),
+                snimpyEmptyDescr=MibTableColumn(
+                    (1, 3, 6, 1, 2, 1, 45121, 2, 6, 1, 2),
+                    v2c.OctetString()).setMaxAccess("readwrite")))
+
+        mibBuilder.exportSymbols(*args, **kwargs)
+
         # Start agent
         cmdrsp.GetCommandResponder(snmpEngine, snmpContext)
         cmdrsp.SetCommandResponder(snmpEngine, snmpContext)
